@@ -47,7 +47,7 @@ pub(crate) async fn validate_zip(
 
     let target = tempfile::TempDir::new()?;
 
-    uv_extract::stream::unzip(reader.compat(), target.path()).await?;
+    uv_extract::stream::unzip(args.url.to_url(), reader.compat(), target.path()).await?;
 
     Ok(())
 }
