@@ -5,11 +5,11 @@ use assert_fs::fixture::FileWriteStr;
 use assert_fs::fixture::PathChild;
 use assert_fs::prelude::*;
 
-use crate::common::{TestContext, uv_snapshot};
+use uv_test::uv_snapshot;
 
 #[test]
 fn list_empty_columns() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     uv_snapshot!(context.pip_list()
         .arg("--format")
@@ -25,7 +25,7 @@ fn list_empty_columns() {
 
 #[test]
 fn list_empty_freeze() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     uv_snapshot!(context.pip_list()
         .arg("--format")
@@ -41,7 +41,7 @@ fn list_empty_freeze() {
 
 #[test]
 fn list_empty_json() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     uv_snapshot!(context.pip_list()
         .arg("--format")
@@ -59,7 +59,7 @@ fn list_empty_json() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn list_single_no_editable() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str("MarkupSafe==2.1.3")?;
@@ -100,7 +100,7 @@ fn list_single_no_editable() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn list_outdated_columns() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str("anyio==3.0.0")?;
@@ -141,7 +141,7 @@ fn list_outdated_columns() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn list_outdated_json() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str("anyio==3.0.0")?;
@@ -179,7 +179,7 @@ fn list_outdated_json() -> Result<()> {
 
 #[test]
 fn list_outdated_freeze() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     uv_snapshot!(context.pip_list().arg("--outdated").arg("--format").arg("freeze"), @"
     success: false
@@ -195,7 +195,7 @@ fn list_outdated_freeze() {
 #[test]
 #[cfg(feature = "test-git")]
 fn list_outdated_git() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str(indoc::indoc! {r"
@@ -238,7 +238,7 @@ fn list_outdated_git() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn list_outdated_index() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str("anyio==3.0.0")?;
@@ -282,7 +282,7 @@ fn list_outdated_index() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn list_editable() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Install the editable package.
     uv_snapshot!(context.filters(), context.pip_install()
@@ -328,7 +328,7 @@ fn list_editable() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn list_editable_only() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Install the editable package.
     uv_snapshot!(context.filters(), context.pip_install()
@@ -403,7 +403,7 @@ fn list_editable_only() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn list_exclude() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Install the editable package.
     uv_snapshot!(context.filters(), context.pip_install()
@@ -486,7 +486,7 @@ fn list_exclude() {
 #[cfg(feature = "test-pypi")]
 #[cfg(not(windows))]
 fn list_format_json() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Install the editable package.
     uv_snapshot!(context.filters(), context.pip_install()
@@ -552,7 +552,7 @@ fn list_format_json() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn list_format_freeze() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Install the editable package.
     uv_snapshot!(context.filters(), context
@@ -623,7 +623,7 @@ fn list_format_freeze() {
 
 #[test]
 fn list_legacy_editable() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let site_packages = ChildPath::new(context.site_packages());
 
@@ -675,7 +675,7 @@ Version: 0.22.0
 
 #[test]
 fn list_legacy_editable_invalid_version() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let site_packages = ChildPath::new(context.site_packages());
 
@@ -718,7 +718,7 @@ Version: 0.1-bulbasaur
 #[test]
 #[cfg(feature = "test-pypi")]
 fn list_ignores_quiet_flag_format_freeze() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Install the editable package.
     uv_snapshot!(context.filters(), context
@@ -793,7 +793,7 @@ fn list_ignores_quiet_flag_format_freeze() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn list_target() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str("MarkupSafe==2.1.3\ntomli==2.0.1")?;
@@ -842,7 +842,7 @@ fn list_target() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn list_prefix() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str("MarkupSafe==2.1.3\ntomli==2.0.1")?;
