@@ -3,11 +3,11 @@ use assert_cmd::prelude::*;
 use assert_fs::fixture::ChildPath;
 use assert_fs::prelude::*;
 
-use crate::common::{TestContext, uv_snapshot};
+use uv_test::uv_snapshot;
 
 #[test]
 fn no_arguments() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     uv_snapshot!(context.filters(), context.pip_uninstall(), @"
     success: false
@@ -27,7 +27,7 @@ fn no_arguments() {
 
 #[test]
 fn invalid_requirement() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     uv_snapshot!(context.filters(), context.pip_uninstall()
         .arg("flask==1.0.x"), @"
@@ -45,7 +45,7 @@ fn invalid_requirement() {
 
 #[test]
 fn missing_requirements_txt() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     uv_snapshot!(context.filters(), context.pip_uninstall()
         .arg("-r")
@@ -62,7 +62,7 @@ fn missing_requirements_txt() {
 
 #[test]
 fn invalid_requirements_txt_requirement() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str("flask==1.0.x")?;
@@ -87,7 +87,7 @@ fn invalid_requirements_txt_requirement() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn uninstall() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str("MarkupSafe==2.1.3")?;
@@ -120,7 +120,7 @@ fn uninstall() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn missing_record() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str("MarkupSafe==2.1.3")?;
@@ -154,7 +154,7 @@ fn missing_record() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn uninstall_editable_by_name() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str(&format!(
@@ -195,7 +195,7 @@ fn uninstall_editable_by_name() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn uninstall_by_path() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str(
@@ -236,7 +236,7 @@ fn uninstall_by_path() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn uninstall_duplicate_by_path() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let requirements_txt = context.temp_dir.child("requirements.txt");
     requirements_txt.write_str(
@@ -282,7 +282,7 @@ fn uninstall_duplicate() -> Result<()> {
     use uv_fs::copy_dir_all;
 
     // Sync a version of `pip` into a virtual environment.
-    let context1 = TestContext::new("3.12");
+    let context1 = uv_test::test_context!("3.12");
     let requirements_txt = context1.temp_dir.child("requirements.txt");
     requirements_txt.write_str("pip==21.3.1")?;
 
@@ -294,7 +294,7 @@ fn uninstall_duplicate() -> Result<()> {
         .success();
 
     // Sync a different version of `pip` into a virtual environment.
-    let context2 = TestContext::new("3.12");
+    let context2 = uv_test::test_context!("3.12");
     let requirements_txt = context2.temp_dir.child("requirements.txt");
     requirements_txt.write_str("pip==22.1.1")?;
 
@@ -331,7 +331,7 @@ fn uninstall_duplicate() -> Result<()> {
 /// Uninstall a `.egg-info` package in a virtual environment.
 #[test]
 fn uninstall_egg_info() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let site_packages = ChildPath::new(context.site_packages());
 
@@ -393,7 +393,7 @@ fn normcase(s: &str) -> String {
 /// Uninstall a legacy editable package in a virtual environment.
 #[test]
 fn uninstall_legacy_editable() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let site_packages = ChildPath::new(context.site_packages());
 
@@ -449,7 +449,7 @@ Version: 0.22.0
 
 #[test]
 fn dry_run_uninstall_egg_info() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let site_packages = ChildPath::new(context.site_packages());
 
